@@ -11,23 +11,23 @@ from typing import Any, Generator, Union
 from typing_extensions import Literal
 
 if __name__ == "__main__":
-    from paths import *
-    from projects import Project
-    from utils import *
-
+    import data_getters as dg
     import lims2 as lims
     import mtrain
 
-    import data_getters as dg
-else:
-    from .paths import *
-    from .projects import Project
-    from .utils import *
+    from utils import *
+    from paths import *
+    from projects import Project
 
+else:
+    from . import data_getters as dg
     from . import lims2 as lims
     from . import mtrain
 
-    from . import data_getters as dg
+    from .utils import *
+    from .paths import *
+    from .projects import Project
+
 
 PathLike = Union[str, bytes, os.PathLike, pathlib.Path]
 # https://peps.python.org/pep-0519/#provide-specific-type-hinting-support
@@ -84,18 +84,27 @@ class Session:
     '576323'
 
     """
+    def __lt__(self, other: Session) -> bool:
+        if not hasattr(other, 'date'):
+            return NotImplemented
+        return self.date < other.date
 
-    def __init__(self, path: PathLike):
+    def __repr__(self) -> str:
+        return f'{__class__.__name__}({self.folder!r})'
 
-        path = pathlib.Path(path)
-
-        np_folder = folder(path)
+    def __init__(self, path_or_session: PathLike | int):
+        
+        path_or_session = str(path_or_session)
+        
+        path_or_session = pathlib.Path(path_or_session)
+        
+        np_folder = folder(path_or_session)
 
         if not np_folder:
-            np_folder = folder_from_lims_id(path)
+            np_folder = folder_from_lims_id(path_or_session)
 
         if np_folder is None:
-            raise SessionError(f"{path} does not contain a valid lims session id or session folder string")
+            raise SessionError(f"{path_or_session} does not contain a valid lims session id or session folder string")
 
         self.folder = np_folder
         self.id = self.folder.split("_")[0]
@@ -168,7 +177,7 @@ class Session:
         "Expected default path, or alternative if one exists"
         return self.qc_paths[0] if self.qc_paths else QC_PATHS[0] / self.folder
     
-    @cached_property
+    @functools.cached_property
     def qc_paths(self) -> list[pathlib.Path]:
         "Any QC folders that exist"
         return [path / self.folder for path in QC_PATHS if (path / self.folder).exists()]    
@@ -177,8 +186,8 @@ class Session:
     def project(self) -> str | None:
         return self.lims.get("project", {}).get("name", None)
 
-    @cached_property
-    def lims_data_getter(self) -> dg.dat | None:
+    @functools.cached_property
+    def lims_data_getter(self) -> dg.data_getter | None:
         try:
             return dg.lims_data_getter(self.id)
         except ConnectionError:
